@@ -1047,9 +1047,11 @@ ccenv_set_os_pe()
 		case "$ccenv_cchost" in
 			*-midipix | *-midipix-* )
 				ccenv_os='midipix' ;;
+			*-windows-gnu )
+				ccenv_os='mingw' ;;
 			*-mingw | *-mingw32 | *-mingw64 )
 				ccenv_os='mingw' ;;
-			*-mingw-* | *-mingw32-* | *-mingw64 )
+			*-mingw-* | *-mingw32-* | *-mingw64-* )
 				ccenv_os='mingw' ;;
 			*-msys | *-msys2 | *-msys-* | *-msys2-* )
 				ccenv_os='msys' ;;
@@ -1081,16 +1083,24 @@ ccenv_set_os_pe()
 
 	if [ -z "$ccenv_os" ] && [ -n "$ccenv_objdump_bfd" ]; then
 		$ccenv_objdump_bfd -x $ccenv_image          \
-			| grep -i 'DLL Name' | grep '.CRT'  \
+			| grep -i 'DLL Name'                \
 				> /dev/null                 \
 		&& $ccenv_objdump_bfd -x $ccenv_image       \
-			| grep -i 'DLL Name' | grep '.bss'  \
+			| grep '.CRT'                       \
 				> /dev/null                 \
 		&& $ccenv_objdump_bfd -x $ccenv_image       \
-			| grep -i 'DLL Name' | grep '.tls'  \
+			| grep '.bss'                       \
+				> /dev/null                 \
+		&& $ccenv_objdump_bfd -x $ccenv_image       \
+			| grep '.tls'                       \
 				> /dev/null                 \
 		&& ccenv_os='mingw'
 	fi
+
+	if [ -z "$ccenv_os" ]; then
+		error_msg "ccenv_set_os_pe: failed to detect the host operating system."
+		config_failure
+	fi
 }
 
 ccenv_set_os_macho()
@@ -1140,6 +1150,12 @@ ccenv_set_os()
 			;;
 	esac
 
+	case "$ccenv_os" in
+		*-linux | linux-* )
+			ccenv_os='linux'
+			;;
+	esac
+
 	if [ -z "$ccenv_os" ]; then
 		ccenv_os='anyos'
 	fi
@@ -1696,6 +1712,41 @@ ccenv_set_cc_linker_switch_vars()
 	done
 }
 
+ccenv_set_cc_attr_vars()
+{
+	if cfgtest_attr_presence 'visibility'; then
+		ccenv_attr_visibility="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'nonnull'; then
+		ccenv_attr_nonnull="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'format'; then
+		ccenv_attr_format="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'malloc'; then
+		ccenv_attr_malloc="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'noreturn'; then
+		ccenv_attr_noreturn="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'deprecated'; then
+		ccenv_attr_deprecated="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'unused'; then
+		ccenv_attr_unused="$mb_cfgtest_attr"
+	fi
+
+	if cfgtest_attr_presence 'always_inline'; then
+		ccenv_attr_always_inline="$mb_cfgtest_attr"
+	fi
+}
+
 ccenv_set_cc_attr_visibility_vars()
 {
 	if cfgtest_attr_visibility 'default'; then
@@ -1823,6 +1874,7 @@ ccenv_set_toolchain_variables()
 	ccenv_set_os_pe_switches
 	ccenv_set_os_gate_switches
 	ccenv_set_os_bsd_switches
+	ccenv_set_cc_attr_vars
 	ccenv_set_cc_attr_visibility_vars
 
 	ccenv_output_defs
