@@ -264,8 +264,6 @@ int slbt_ar_merge_archives(
 					break;
 
 				case AR_MEMBER_ATTR_NAMESTRS:
-					snamestrs += meminfo->ar_object_size;
-
 					if (!arnames)
 						arnames = meminfo;
 
@@ -282,6 +280,8 @@ int slbt_ar_merge_archives(
 					break;
 			}
 		}
+
+		snamestrs += (slbt_archive_meta_ictx(meta))->sreqsize;
 	}
 
 	/* armap size */
