@@ -326,10 +326,13 @@ int slbt_ar_get_archive_meta(
 	const char *                    slash;
 	const char *                    ch;
 	const char *                    fldcap;
+	const char *                    namemark;
 	size_t				nelements;
 	uint64_t                        nentries;
 	uint64_t                        nmembers;
 	uint64_t                        stblsize;
+	uint64_t                        sreqsize;
+	uint64_t                        rnamelen;
 	uint64_t                        filesize;
 	uint64_t                        namelen;
 	uint64_t                        nameoff;
@@ -404,7 +407,11 @@ int slbt_ar_get_archive_meta(
 						SLBT_ERR_AR_INVALID_HEADER));
 
 	/* count entries, calculate string table size */
-	for (nentries=0,stblsize=0,arlongnames=0; mark<cap; nentries++) {
+	stblsize    = 0;
+	sreqsize    = 0;
+	arlongnames = 0;
+
+	for (nentries=0; mark<cap; nentries++) {
 		arhdr = (struct ar_raw_file_header *)mark;
 
 		/* file size */
@@ -454,7 +461,8 @@ int slbt_ar_get_archive_meta(
 			stblsize++;
 			stblsize++;
 
-			stblsize += namelen;
+			namemark  = &arhdr->ar_file_id[0];
+			namemark += sizeof(struct ar_raw_file_header);
 
 			arlongnames = arhdr;
 
@@ -487,6 +495,17 @@ int slbt_ar_get_archive_meta(
 				stblsize++;
 			} else {
 				attr = AR_HEADER_ATTR_NAME_REF | AR_HEADER_ATTR_SYSV;
+
+				ch = &namemark[nameoff];
+
+				for (; *ch && (*ch != '/') && (*ch != AR_OBJ_PADDING); )
+					ch++;
+
+				/* stblsize: internal string table, strings are null terminated */
+				/* sreqsize: arlongnames, strings are terminated by 0x27 0x0a   */
+				rnamelen  = (ch - &namemark[nameoff]);
+				stblsize += rnamelen + 1;
+				sreqsize += rnamelen + 1 + 1;
 			}
 
 		/* bsd long name reference? */
@@ -580,6 +599,10 @@ int slbt_ar_get_archive_meta(
 		hdrinfov[nentries].attr = attr;
 	}
 
+	/* store size of string table */
+	m->stblsize = stblsize;
+	m->sreqsize = sreqsize;
+
 	/* allocate name strings, member vector */
 	if (!(m->namestrs = calloc(1,stblsize)))
 		return slbt_ar_free_archive_meta_impl(
