@@ -653,10 +653,10 @@ int slbt_lib_get_driver_ctx(
 				case TAG_IMPLIB:
 					if (!strcmp("idata",entry->arg)) {
 						cctx.drvflags |= SLBT_DRIVER_IMPLIB_IDATA;
-						cctx.drvflags &= ~(uint64_t)SLBT_DRIVER_IMPLIB_DSOMETA;
+						cctx.drvflags &= ~(uint64_t)SLBT_DRIVER_IMPLIB_DSODEPS;
 
 					} else if (!strcmp("never",entry->arg)) {
-						cctx.drvflags |= SLBT_DRIVER_IMPLIB_DSOMETA;
+						cctx.drvflags |= SLBT_DRIVER_IMPLIB_DSODEPS;
 						cctx.drvflags &= ~(uint64_t)SLBT_DRIVER_IMPLIB_IDATA;
 					}
 
