@@ -39,6 +39,8 @@ struct slbt_archive_meta_impl {
 	struct slbt_archive_ctx *       actx;
 	size_t                          ofmtattr;
 	size_t                          nentries;
+	size_t                          stblsize;
+	size_t                          sreqsize;
 	void *                          hdrinfov;
 	char *                          namestrs;
 	const char *                    symstrs;
