@@ -37,7 +37,7 @@ slbt_hidden int slbt_exec_link_create_import_library(
 	char    as[PATH_MAX];
 
 	/* dlltool or mdso? */
-	if (dctx->cctx->drvflags & SLBT_DRIVER_IMPLIB_DSOMETA)
+	if (dctx->cctx->drvflags & SLBT_DRIVER_IMPLIB_DSODEPS)
 		fmdso = 1;
 
 	else if (dctx->cctx->drvflags & SLBT_DRIVER_IMPLIB_IDATA)
