@@ -164,10 +164,10 @@ const slbt_hidden struct argv_option slbt_default_options[] = {
 				"to be used."},
 
 	{"implib",		0,TAG_IMPLIB,ARGV_OPTARG_REQUIRED,0,
-				"idata|dsometa",0,
+				"idata|dsodeps",0,
 				"PE import libraries should either use the legacy "
 				"format (.idata section) and be generated by dlltool, "
-				"or the custom format (.dsometa section) and be "
+				"or the custom format (.dsodeps section) and be "
 				"generated by mdso."},
 
 	{"warnings",		0,TAG_WARNINGS,ARGV_OPTARG_REQUIRED,0,
